@@ -1,5 +1,5 @@
 package Net::Amazon::S3::Client::Object;
-$Net::Amazon::S3::Client::Object::VERSION = '0.93';
+$Net::Amazon::S3::Client::Object::VERSION = '0.94';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 use DateTime::Format::HTTP;
@@ -126,7 +126,7 @@ sub get_decoded {
 sub get_callback {
     my ( $self, $callback ) = @_;
 
-    my $response = $self->_fetch_response (
+    my $response = $self->__perform_operation (
         response_class => 'Net::Amazon::S3::Operation::Object::Fetch::Response',
         request_class  => 'Net::Amazon::S3::Operation::Object::Fetch::Request',
         filename       => $callback,
@@ -140,7 +140,7 @@ sub get_callback {
 sub get_filename {
     my ( $self, $filename ) = @_;
 
-    my $response = $self->_fetch_response (
+    my $response = $self->__perform_operation (
         response_class => 'Net::Amazon::S3::Operation::Object::Fetch::Response',
         request_class  => 'Net::Amazon::S3::Operation::Object::Fetch::Request',
         filename       => $filename,
@@ -543,7 +543,7 @@ Net::Amazon::S3::Client::Object - An easy-to-use Amazon S3 client object
 
 =head1 VERSION
 
-version 0.93
+version 0.94
 
 =head1 SYNOPSIS
 
